@@ -1,4 +1,5 @@
 import os
+from pathlib import Path
 from .bmw_file import BMWFile
 from datetime import datetime
 
@@ -39,6 +40,10 @@ class BMWData1File(BMWFile):
 
             return
 
+        # Create directories if necessary
+        path, _ = os.path.split(destination)
+        Path(path).mkdir(parents=True, exist_ok=True)
+
         with open(self._filename, "rb") as source_file:
             with open(destination, "wb") as destination_file:
                 destination_file.write(source_file.read())
